==> ruby-async-io-1.16.3-2-any.pkg.tar.xz: usr/lib/ruby/gems/2.6.0/gems/async-io-1.16.3/spec/async/io/trap_spec.rb <==
# Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

require 'async/io/trap'

RSpec.describe Async::IO::Trap do
	include_context Async::RSpec::Reactor
	
	subject {described_class.new(:USR1)}
	
	it "should wait for signal" do
		trapped = false
		
		waiting_task = reactor.async do
			subject.trap do
				trapped = true
				break
			end
		end
		
		subject.trigger
		
		waiting_task.wait
		
		expect(trapped).to be_truthy
	end
end

==> ruby-async-io-1.27.0-2-any.pkg.tar.xz: usr/lib/ruby/gems/2.7.0/gems/async-io-1.27.0/spec/async/io/trap_spec.rb <==
# Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

require 'async/io/trap'

RSpec.describe Async::IO::Trap do
	include_context Async::RSpec::Reactor
	
	subject {described_class.new(:USR2)}
	
	it "can ignore signal" do
		subject.ignore!
		
		Process.kill(:USR2, Process.pid)
	end
	
	it "should wait for signal" do
		trapped = false
		
		waiting_task = reactor.async do
			subject.wait do
				trapped = true
				break
			end
		end
		
		subject.trigger
		
		waiting_task.wait
		
		expect(trapped).to be_truthy
	end
end
